pub struct Client { /* private fields */ }Expand description
Client for invoking serverless functions.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn new() -> Result<Self, ServerlessError>
pub fn new() -> Result<Self, ServerlessError>
Creates a new client with default configuration.
Errors
Returns an error if the client cannot be created.
Sourcepub fn with_config(config: Config) -> Result<Self, ServerlessError>
pub fn with_config(config: Config) -> Result<Self, ServerlessError>
Creates a new client with custom configuration.
Errors
Returns an error if the client cannot be created.
Sourcepub async fn call_function(
&self,
function_name: &str,
payload: Vec<u8>,
headers: Option<HashMap<String, String>>,
) -> Result<Vec<u8>, ServerlessError>
pub async fn call_function( &self, function_name: &str, payload: Vec<u8>, headers: Option<HashMap<String, String>>, ) -> Result<Vec<u8>, ServerlessError>
Sourcepub fn serializer(&self) -> &Serializer
pub fn serializer(&self) -> &Serializer
Returns a reference to the underlying serializer.